==> libreoffice_6.4.2.orig.tar.xz: libreoffice-6.4.2/oox/source/drawingml/chart/titlemodel.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <drawingml/chart/titlemodel.hxx>
#include <oox/token/tokens.hxx>

namespace oox {
namespace drawingml {
namespace chart {

TextModel::TextModel()
{
}

TextModel::~TextModel()
{
}

TitleModel::TitleModel(sal_Int32 nDefaultRotation) :
    mbOverlay( false ),
    mnDefaultRotation(nDefaultRotation)
{
}

TitleModel::~TitleModel()
{
}

LegendEntryModel::LegendEntryModel() :
    mnLegendEntryIdx( -1 ),
    mbLabelDeleted( false )
{
}

LegendEntryModel::~LegendEntryModel()
{
}

LegendModel::LegendModel(bool bMSO2007Doc) :
    mnPosition( XML_r ),
    mbOverlay( !bMSO2007Doc )
{
}

LegendModel::~LegendModel()
{
}

} // namespace chart
} // namespace drawingml
} // namespace oox

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_7.0.4.orig.tar.xz: libreoffice-7.0.4.2/oox/source/drawingml/chart/titlemodel.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <drawingml/chart/titlemodel.hxx>
#include <oox/token/tokens.hxx>

namespace oox::drawingml::chart {

TextModel::TextModel()
{
}

TextModel::~TextModel()
{
}

TitleModel::TitleModel(sal_Int32 nDefaultRotation) :
    mbOverlay( false ),
    mnDefaultRotation(nDefaultRotation)
{
}

TitleModel::~TitleModel()
{
}

LegendEntryModel::LegendEntryModel() :
    mnLegendEntryIdx( -1 ),
    mbLabelDeleted( false )
{
}

LegendEntryModel::~LegendEntryModel()
{
}

LegendModel::LegendModel() :
    mnPosition( XML_r ),
    mbOverlay( false )
{
}

LegendModel::~LegendModel()
{
}

} // namespace oox::drawingml::chart

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
